#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 postgrest
version:              10.1.0
visibility:           public
id:                   postgrest-10.1.0-APrucZUECji4SE7NQy3LpH
key:                  postgrest-10.1.0-APrucZUECji4SE7NQy3LpH
license:              MIT
maintainer:           Steve Chavez <stevechavezast@gmail.com>
author:               Joe Nelson, Adam Baker, Steve Chavez
homepage:             https://postgrest.org
synopsis:             REST API for any Postgres database
description:
    Reads the schema of a PostgreSQL database and creates RESTful routes
    for tables, views, and functions, supporting all HTTP methods that security
    permits.

category:             Executable, PostgreSQL, Network APIs
abi:                  7e41c1f1ef1f61e1ce41388a68940d13
exposed:              True
exposed-modules:
    PostgREST.ApiRequest PostgREST.ApiRequest.Preferences
    PostgREST.ApiRequest.QueryParams PostgREST.ApiRequest.Types
    PostgREST.App PostgREST.AppState PostgREST.Auth PostgREST.CLI
    PostgREST.Config PostgREST.Config.Database PostgREST.Config.JSPath
    PostgREST.Config.PgVersion PostgREST.Config.Proxy PostgREST.Cors
    PostgREST.Error PostgREST.Logger PostgREST.MediaType PostgREST.Plan
    PostgREST.Plan.CallPlan PostgREST.Plan.MutatePlan
    PostgREST.Plan.ReadPlan PostgREST.Query
    PostgREST.Query.QueryBuilder PostgREST.Query.SqlFragment
    PostgREST.Query.Statements PostgREST.RangeQuery PostgREST.Response
    PostgREST.Response.GucHeader PostgREST.Response.OpenAPI
    PostgREST.SchemaCache PostgREST.SchemaCache.Identifiers
    PostgREST.SchemaCache.Proc PostgREST.SchemaCache.Relationship
    PostgREST.SchemaCache.Table PostgREST.Unix PostgREST.Version
    PostgREST.Workers

hidden-modules:       Paths_postgrest
import-dirs:          /usr/lib/ghc-9.6.6/site-local/postgrest-10.1.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/postgrest-10.1.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/postgrest-10.1.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/postgrest
hs-libraries:         HSpostgrest-10.1.0-APrucZUECji4SE7NQy3LpH
depends:
    HTTP-4000.5.0-LDby5ZACPybDDeyuZwXSBN
    Ranged-sets-0.5.0-3sOw99T9iy9EkodbUqt4kN
    aeson-2.2.2.0-HX3VmpxSu7MBeXlY03a2B0
    auto-update-0.1.6-ys6z8OSxC8EGjAXlDjvjY base-4.18.2.1
    base64-bytestring-1.2.1.0-7bYUUcNMltODtdJX73Bu5o
    bytestring-0.11.5.3 case-insensitive-1.2.1.0-2eph4zYoAFzHEvr0xd94hH
    cassava-0.5.4.1-8vgm2VgiZ5K8MeeHXtzAzX
    configurator-pg-0.2.11-YhFIpcwBS5DfAF5AmaOTi containers-0.6.7
    contravariant-extras-0.3.5.4-Jp1EzHgD0E5KQ707vKnuxI
    cookie-0.5.0-Dqi2dsQ09KG8Z0mbWITxu5 directory-1.3.8.5
    either-5.0.3-4tr4rvsXIekxhVIxYYnuv
    gitrev-1.3.1-HjgHeGOzFY1JvYhlt8eDSs
    hasql-1.6.1.1-I6m7Cir6AuUG3tRQxJ9Bye
    hasql-dynamic-statements-0.3.1.2-F2X0R1Nngmw47o4nCEl83j
    hasql-notifications-0.2.0.5-6xDT3QMriy25bz1L6yXmt
    hasql-pool-0.8.0.2-6EttXNAjke7oZeghKp8Xa
    hasql-transaction-1.0.1.2-3br4jpP1hPJC2no3DSNq4h
    heredoc-0.2.0.0-6fzsisYvDUd6tBbd4jIzIt
    http-types-0.12.4-1JnQTH18RU0DibFo35M5JY
    insert-ordered-containers-0.2.5.3-GcE2NiJB1VV64pr2K5O5Vg
    interpolatedstring-perl6-1.0.2-4JVfcsUhSpQClD1sam7oh
    jose-0.10.0.1-1s03eTXfQO19yx0LX9RjSL
    lens-5.3.4-1IL9mxUdyyZ2Td3b3fp10G
    lens-aeson-1.2.3-2L3IMbgxyk3HzNxitqHDf2 mtl-2.3.1
    network-3.1.4.0-D5In1g0c1o5Lno6WiKQzlZ
    network-uri-2.6.4.2-EPISvuAciHNCNyhUbkgF33
    optparse-applicative-0.18.1.0-2Hiadv6BpzgDgx5QxnTvo5
    parsec-3.1.16.1 protolude-0.3.5-LP9DRLdLFKl6fhzdPgWtNV
    regex-tdfa-1.3.2.5-H8j3gUuup0uJLVNboVGbR5
    retry-0.9.3.1-7eRqrbYk2bRGl9jVYYNBVW
    scientific-0.3.8.1-652cwqsM8CP9x29NG2IMof
    swagger2-2.8.10-IBUY3ZP0G1D3IHEjb8orgN text-2.0.2 time-1.12.2
    unix-2.8.4.0 unordered-containers-0.2.20.1-F8uKhGV3AlWbjcYkQjkcw
    vault-0.3.1.6-EZlr2vE0z7aIw8XGIsbGWX
    vector-0.13.2.0-DMZHGTdGAnaIWH7Z4Bo5hL
    wai-3.2.4-26S7wSgs7zh6r23sUbEeda
    wai-cors-0.2.7-JH0u4pTq3loFNMU4nnPRLz
    wai-extra-3.1.18-DVxZKLXzOi8EUNDpgGre05
    wai-logger-2.5.0-1h0tQYUKm65KAB89VfzX2h
    warp-3.4.0-CU9DedNWv0uIPGnaUEfcpM

haddock-interfaces:   /usr/share/doc/postgrest/html/postgrest.haddock
haddock-html:         /usr/share/doc/postgrest/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

